==> hadoop-hdfs-client-2.8.1-sources.jar: org/apache/hadoop/hdfs/web/resources/DelegationParam.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.web.resources;

import org.apache.hadoop.security.UserGroupInformation;

/** Represents delegation token used for authentication. */
public class DelegationParam extends StringParam {
  /** Parameter name. */
  public static final String NAME = "delegation";
  /** Default parameter value. */
  public static final String DEFAULT = "";

  private static final Domain DOMAIN = new Domain(NAME, null);

  /**
   * Constructor.
   * @param str a string representation of the parameter value.
   */
  public DelegationParam(final String str) {
    super(DOMAIN, UserGroupInformation.isSecurityEnabled()
        && str != null && !str.equals(DEFAULT)? str: null);
  }

  @Override
  public String getName() {
    return NAME;
  }
}

==> hadoop-hdfs-client-3.2.0.15-20241022.151236-47-sources.jar: org/apache/hadoop/hdfs/web/resources/DelegationParam.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.web.resources;

import org.apache.hadoop.security.UserGroupInformation;

/**
 * Represents delegation token used for authentication.
 */
public class DelegationParam extends StringParam {
  /**
   * Parameter name.
   */
  public static final String NAME = "delegation";
  /**
   * Default parameter value.
   */
  public static final String DEFAULT = "";

  private static final Domain DOMAIN = new Domain(NAME, null);

  /**
   * Constructor.
   *
   * @param str
   *     a string representation of the parameter value.
   */
  public DelegationParam(final String str) {
    super(DOMAIN, UserGroupInformation.isSecurityEnabled() && str != null &&
        !str.equals(DEFAULT) ? str : null);
  }

  @Override
  public String getName() {
    return NAME;
  }
}
